Dipusテスト
=============

This is the test document for dipus.


Sphinx-Users.jp(略称#sphinxjp)は、美しいドキュメントを簡単に生成することができる、Sphinx（スフィンクス）の普及を主眼としたコミュニティです。このSphinx-Users.jpのサイトもSphinxを使って作られています。

日本で散らばっているSphinx関連情報を集めて、Webサイト、イベントを通じてSphinx情報を発信します。また、メーリングリストでの情報交換、 勉強会の開催などを通じて、ドキュメントをパワーアップしたい人、ドキュメントや翻訳で苦労している人、Sphinxの拡張機能を開発したい開発者たちに”Fun”を提供していきます。


参加方法
----------------

ご自由に メーリングリスト にご参加ください。また、Sphinx-Users.jpが行うイベントも定期的に行います。

イベント情報などは、Twitterの SphinxUsers.jp公式アカウント でも呟きます。また、コミュニティのハッシュタグは #sphinxjp になります。

もし、ここに掲載している内容にミスが見つかったり、追加のコンテンツの希望、もしくは「これを載せて」という方は、このサイトのソースをホスティングしている、Bitbukcet内の 課題トラッカー のチケットを作成してください。
